
# Type: anatomical entity to anatomical entity association_subject




URI: [biolink:anatomical_entity_to_anatomical_entity_association_subject](https://w3id.org/biolink/vocab/anatomical_entity_to_anatomical_entity_association_subject)


## Domain and Range

[AnatomicalEntityToAnatomicalEntityAssociation](AnatomicalEntityToAnatomicalEntityAssociation.md) ->  <sub>REQ</sub> [AnatomicalEntity](AnatomicalEntity.md)

## Parents

 *  is_a: [subject](subject.md)

## Children

 *  [anatomical entity to anatomical entity ontogenic association➞subject](anatomical_entity_to_anatomical_entity_ontogenic_association_subject.md)
 *  [anatomical entity to anatomical entity part of association➞subject](anatomical_entity_to_anatomical_entity_part_of_association_subject.md)

## Used by

 * [AnatomicalEntityToAnatomicalEntityAssociation](AnatomicalEntityToAnatomicalEntityAssociation.md)
